pub enum InferenceTask {
Message(Message),
Context(Vec<Message>),
Prompt(Prompt),
}Expand description
The potential tasks that can be executed by an inference job using the inference server.
Variants
Message(Message)
A single message to be processed by the server.
Context(Vec<Message>)
Multiple messages to be processed by the server.
This could be useful to restore a previous session based on text history.
Prompt(Prompt)
Run with a simple prompt.