pub struct InferenceJob {
pub task: InferenceTask,
pub emitter: GeneratedItemEmitter,
}Expand description
Defines a job to be run during inference.
Fields
task: InferenceTaskThe task to be performed by the job.
emitter: GeneratedItemEmitterThe emitter for the current job.
Implementations
Sourceimpl InferenceJob
impl InferenceJob
Sourcepub fn create<L: InferenceJobListener>(
task: InferenceTask,
listener: L,
) -> (Self, JobHandle<L>)
pub fn create<L: InferenceJobListener>( task: InferenceTask, listener: L, ) -> (Self, JobHandle<L>)
Start a new inference job and process it on another thread.
When a task is performed for the current job, it should be registered using the completed method.