pub struct TextGenerationListener { /* private fields */ }Expand description
The text generation listener accumulate the generated text in a string that can be obtained at the end of the job with the handle finished method.